"use client";

import Image from "next/image";
import { useState } from "react";

import { zodResolver } from "@hookform/resolvers/zod";
import { LucideTrash } from "lucide-react";
import { useTranslations } from "next-intl";
import Dropzone from "react-dropzone";
import { useForm } from "react-hook-form";
import * as z from "zod";

import {
	Form,
	FormControl,
	FormField,
	FormItem,
	FormMessage,
} from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";

type MaintenanceFormValues = {
	fullName: string;
	email: string;
	phone: string;
	address: string;
	poolLength: number;
	poolWidth: number;
	poolDepth: number;
	poolType: string;
	images: File[];
};

export default function MaintenanceForm() {
	const t = useTranslations("MaintenanceRequest.Form");

	const formSchema = z.object({
		fullName: z.string().min(1, t("validation.fullName.required")),
		email: z
			.string()
			.email(t("validation.email.invalid"))
			.min(1, t("validation.email.required")),
		phone: z.string().min(1, t("validation.phone.required")),
		address: z.string().url(t("validation.address.invalid")),
		poolLength: z.number().positive(t("validation.poolLength.invalid")),
		poolWidth: z.number().positive(t("validation.poolWidth.invalid")),
		poolDepth: z.number().positive(t("validation.poolDepth.invalid")),
		poolType: z.string().min(1, t("validation.poolType.required")),
		images: z.array(z.any()).min(1, t("validation.images.required")).optional(),
	});

	const [uploadedImages, setUploadedImages] = useState<File[]>([]);
	const form = useForm<MaintenanceFormValues>({
		resolver: zodResolver(formSchema),
		defaultValues: {
			fullName: "",
			email: "",
			phone: "",
			address: "",
			poolLength: 0,
			poolWidth: 0,
			poolDepth: 0,
			poolType: "",
			images: [],
		},
	});

	const onDrop = (acceptedFiles: File[]) => {
		setUploadedImages((prev) => [...prev, ...acceptedFiles]);
		form.setValue("images", [...form.getValues("images"), ...acceptedFiles]);
	};

	const handleRemoveImage = (index: number) => {
		setUploadedImages((prev) => prev.filter((_, i) => i !== index));
	};

	async function onSubmit(values: MaintenanceFormValues) {
		console.log("Form Submitted: ", values);
	}

	const renderFormField = (
		name: keyof MaintenanceFormValues,
		label: string,
		placeholder: string,
		type: string = "text",
		required: boolean = true,
		withLabel = true
	) => (
		<FormField
			control={form.control}
			name={name}
			render={({ field }) => (
				<FormItem>
					{withLabel && (
						<Label>
							<p className="#000 text-base leading-6">
								{label}
								{required && <span className="text-[#EB5757]"> *</span>}
							</p>
						</Label>
					)}
					<FormControl>
						<Input
							{...(field as any)}
							type={type}
							placeholder={placeholder}
							className="h-[56px] rounded-none border-[#DEDEDE]"
						/>
					</FormControl>
					<FormMessage />
				</FormItem>
			)}
		/>
	);

	return (
		<div>
			<Form {...form}>
				<form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
					<div className="grid grid-cols-1 gap-4">
						{renderFormField(
							"fullName",
							t("Label.FullName"),
							t("Placeholder.FullName")
						)}
						{renderFormField(
							"email",
							t("Label.Email"),
							t("Placeholder.Email"),
							"email"
						)}
						{renderFormField("phone", t("Label.Phone"), t("Placeholder.Phone"))}
						{renderFormField(
							"address",
							t("Label.Address"),
							t("Placeholder.Address"),
							"url"
						)}

						<FormField
							control={form.control}
							name="images"
							render={() => (
								<FormItem>
									<Label>{t("Label.Images")}</Label>
									<Dropzone
										onDrop={onDrop}
										// eslint-disable-next-line @typescript-eslint/ban-ts-comment
										//@ts-ignore
										accept={"image/*"}
									>
										{({ getRootProps, getInputProps }) => (
											<div
												{...getRootProps()}
												className="cursor-pointer border-2 border-dashed p-4 text-center"
											>
												<input {...getInputProps()} />
												<p>{t("Placeholder.Images")}</p>
											</div>
										)}
									</Dropzone>
									<div className="mt-4 flex flex-wrap gap-4">
										{uploadedImages?.map((file, index) => (
											<div key={index} className="group relative">
												<Image
													src={URL.createObjectURL(file)}
													alt={file.name}
													width={150}
													height={150}
													className="h-[150px] w-[150px] cursor-pointer rounded-lg object-cover shadow-md"
												/>
												<button
													type="button"
													className="absolute right-2 top-2 rounded-full bg-red-500 p-1 text-white opacity-0 transition-opacity group-hover:opacity-100"
													onClick={() => handleRemoveImage(index)}
												>
													<LucideTrash className="h-4 w-4" />
												</button>
											</div>
										))}
									</div>
									<FormMessage />
								</FormItem>
							)}
						/>
					</div>

					<p className="col-span-12">{t("Placeholder.PoolDimensions")}</p>
					<div className="grid grid-cols-4 gap-4">
						{renderFormField(
							"poolLength",
							t("Label.PoolLength"),
							t("Placeholder.PoolLength"),
							"text",
							true,
							false
						)}
						{renderFormField(
							"poolWidth",
							t("Label.PoolWidth"),
							t("Placeholder.PoolWidth"),
							"text",
							true,
							false
						)}
						{renderFormField(
							"poolDepth",
							t("Label.PoolDepth"),
							t("Placeholder.PoolDepth"),
							"text",
							true,
							false
						)}
						{renderFormField(
							"poolType",
							t("Label.PoolType"),
							t("Placeholder.PoolType"),
							"text",
							true,
							false
						)}
					</div>

					<div className="col-span-12 flex justify-center">
						<div className="w-fit rounded-[999px] bg-[#606676] px-24 py-2 text-center text-white">
							<p className="mb-1 text-lg font-normal">{t("FinalPrice")}</p>
							<p className="text-xl font-normal">254 {t("SaudiRiyal")}</p>
						</div>
					</div>

					<button
						type="submit"
						className="h-12 w-full rounded bg-custom-primary-accent text-2xl font-normal text-white"
					>
						{t("Button.Submit")}
					</button>
				</form>
			</Form>
		</div>
	);
}
